component extends="testbox.system.BaseSpec"{


	function clearDB(){
	
		//Wipe the db
		queryExecute("DELETE FROM card_processor");
		queryExecute("DELETE FROM card_processor_type");

	};

	function run(){
		ormReload();
		describe( "ORM fails in transaction", function(){
		



			it( "should save all the items", function(){


				clearDB();

				var id1 = replace(createUUID(), "-", "", "all");
				var id2 = replace(createUUID(), "-", "", "all");
				var item1 = EntityNew("CardProcessor", {id:id1, name:"TestCardProcessor"});
				var item2 = EntityNew("CardProcessorType", {id:id2, label:"Merchantware"});

				
				transaction {
					EntitySave(item1);
					EntitySave(item2);

					transactionCommit();
				}

				ormFlush();

				var res1 = queryExecute("SELECT * FROM card_processor");
				var res2 = queryExecute("SELECT * FROM card_processor_type");


				expect(	res1.recordcount ).toBe(1);
				expect(	res2.recordcount ).toBe(1);
				
			});

			it( "should save some items even if we have a throw", function(){

				clearDB();

				// There is an issue when an ORM bug is thrown (maxlength of field exceeded for instance), the transaction does not fail, and any further transactions on the page fail as well.

				//Current Count

				var start1 = queryExecute("SELECT * FROM card_processor");
				var start2 = queryExecute("SELECT * FROM card_processor_type");

				var id1 = replace(createUUID(), "-", "", "all");
				var id2 = "VERY-LONG-ID-THAT-SHOULD-NOT-SAVE-IN-THE-DB";
				var item1 = EntityNew("CardProcessor", {id:id1, name:"TestCardProcessor"});
				var item2 = EntityNew("CardProcessorType", {id:id2, label:"Merchantware"}); //this should not save, the IUD is too long
	
				transaction {
						EntitySave(item1);
						transactionCommit();
				}

				//Should throw an exception
				expect(	 function(){
					transaction {
							EntitySave(item2);
							transactionCommit();
					}

				} ).toThrow(  );


			
				ormFlush();

				var end1 = queryExecute("SELECT * FROM card_processor");
				var end2 = queryExecute("SELECT * FROM card_processor_type");

				expect( end1.recordcount ).toBe( start1.recordcount + 1, "Was expecting the item 1 to be saved" );
				expect( end2.recordcount ).toBe( start2.recordcount , "Was expecting the item 2 not to be saved");
			});
		
		});
	}
}